@@ -9,7 +9,7 @@ import wx.lib.intctrl
 import wx.lib.masked.timectrl
 import wx.lib.stattext
 import tuner
-import popen2
+import subprocess
 import urllib
 #import mx.DateTime
 import time
@@ -247,8 +247,7 @@ class RecordStream(wx.Dialog):
         args +=' -l '+str((self.stophours.GetValue()*3600)+(self.stopmins.GetValue()*60))     
         print ('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
             +' '+self.datechoice.GetStringSelection()+'\n'+'call: '+args)
-        atcommand=popen2.Popen4('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
-            +' '+self.datechoice.GetStringSelection())
-        atcommand.tochild.write(args)
-        atcommand.tochild.close()
+        atcommand=subprocess.Popen('at '+self.time.GetValue()+' '+self.monthchoice.GetStringSelection()\
+            +' '+self.datechoice.GetStringSelection(),shell=True, close_fds=True, stdin=subprocess.PIPE)
+        atcommand.communicate(args)
         self.Close()
