@@ -1,5 +1,5 @@
 #Boa:Frame:TunapieFrame
-#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2009 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 2.0.16 23/10/08
+#Version 2.0.17 30/01/09
 
 import wx
 from wx.lib.anchors import LayoutAnchors
@@ -378,17 +378,20 @@ class TunapieFrame(wx.Frame):
             geomfile=open(self.home+'/.tunapie/geom','r')
             geometry=geomfile.read().split('\n')
             size=geometry[0].split(' ')
-            self.SetSize(wx.Size(int(size[0]),int(size[1])))
-            pos=geometry[1].split(' ')
-            self.SetPosition(wx.Point(int(pos[0]),int(pos[1])))
-            self.mainsplitter.SetSashPosition(int(geometry[2]))
-            self.favesplitter.SetSashPosition(int(geometry[3]))
-            maincolumnwidths=geometry[4].split(' ')
-            for i in range(6):
-                self.MainListCtrl.SetColumnWidth(i,int(maincolumnwidths[i]))
-            favecolumnwidths=geometry[5].split(' ')
-            for i in range(6):
-                self.FaveListCtrl.SetColumnWidth(i,int(favecolumnwidths[i]))
+            try:
+            	self.SetSize(wx.Size(int(size[0]),int(size[1])))
+            	pos=geometry[1].split(' ')
+            	self.SetPosition(wx.Point(int(pos[0]),int(pos[1])))
+            	self.mainsplitter.SetSashPosition(int(geometry[2]))
+            	self.favesplitter.SetSashPosition(int(geometry[3]))
+            	maincolumnwidths=geometry[4].split(' ')
+            	for i in range(6):
+                	self.MainListCtrl.SetColumnWidth(i,int(maincolumnwidths[i]))
+            	favecolumnwidths=geometry[5].split(' ')
+            	for i in range(6):
+                	self.FaveListCtrl.SetColumnWidth(i,int(favecolumnwidths[i]))
+            except ValueError:
+            	pass
         except IOError:
             pass          
         self.radioselected=1 #radioselected? Needed??
@@ -1101,7 +1104,7 @@ class TunapieFrame(wx.Frame):
                 self.lastmod=1
                 try:
                     self.running=1
-                    tuner.playselection(self.mediaplayer,self.favurl[selection],0)
+                    thread.start_new_thread(tuner.playselection, (self.mediaplayer,self.favurl[selection],0))
                 except IOError:
                     self.contacterror()
             return
@@ -1122,7 +1125,7 @@ class TunapieFrame(wx.Frame):
         if(self.radioselected):
             try: 
                 self.running=1
-                tuner.playselection(self.mediaplayer,self.url[selection],0)
+                thread.start_new_thread(tuner.playselection,(self.mediaplayer,self.url[selection],0))
             except IOError: #if try to play empty stream!
                 self.contacterror()
         return
@@ -1441,9 +1444,9 @@ class TunapieFrame(wx.Frame):
     def OnFilemenuReloadMenu(self, event):
         if self.reloading==1:
             return
-        if self.running:
-            tuner.pkill(self.videoplayer[self.videoplayer.rfind("/")+1:len(self.videoplayer)])
-            tuner.pkill(self.mediaplayer[self.mediaplayer.rfind("/")+1:self.mediaplayer.rfind("/")+16])
+        #if self.running:
+        #    tuner.pkill(self.videoplayer[self.videoplayer.rfind("/")+1:len(self.videoplayer)])
+        #    tuner.pkill(self.mediaplayer[self.mediaplayer.rfind("/")+1:self.mediaplayer.rfind("/")+16])
         self.reloading=1
         self.downloading=0
         self.setgenreboxradio()
